@@ -30,20 +30,23 @@
 
 #include "weather-event.h"
 
-void timer_handler(gpointer data){
+static GSList *event_time_list = NULL;
+
+gboolean 
+timer_handler(gpointer data){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     time_t current_time;
 
     if(not_event == TRUE || !event_time_list)
-	return;
+	return TRUE;
 
     list_time_event_temp = event_time_list;  
     /* get current time */  
     current_time = time(NULL);
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
-	if(evt->time < current_time){
+	if(evt->time <= current_time){
 	    switch(evt->type_event){
 		case DAYTIMEEVENT :
      		    weather_frame_update(FALSE);   
@@ -52,8 +55,9 @@ void timer_handler(gpointer data){
 		    /* Reinitialise autoupdate event */ 
 		    /* delete periodic update */
                     event_time_list=g_slist_remove(event_time_list,event_time_list->data);
-		    if(get_weather_html(FALSE) == 0)
-			weather_frame_update(FALSE);
+		    fprintf(stderr,"UPDATE by event\n");
+		    app->show_update_window = FALSE;
+		    update_weather();
                     /* add periodic update */
                     add_periodic_event();
     		break;		    
@@ -62,8 +66,10 @@ void timer_handler(gpointer data){
 	}             
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
+return TRUE;    
 }
 
+/*For debug */
 void print_list(void){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
@@ -73,12 +79,15 @@ void print_list(void){
     list_time_event_temp = event_time_list;  
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
+	fprintf(stderr,"Time: %s,Event: %i\n",ctime(&evt->time),evt->type_event);
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
 }
 
 void timer(void){
-    flag_event = g_timeout_add (60000, (GtkFunction)timer_handler, box); /* One per minute */
+    g_timeout_add(60000,
+		    (GtkFunction)timer_handler,
+		    app->main_window); /* One per minute */
 }
 
 /* Free memory allocated for time event */
@@ -118,8 +127,8 @@ void time_event_add(time_t time_value,short int type_event){
 
 /* Add periodic time event  to list */	  
 void add_periodic_event(void){
-    if(_weather_periodic_update > 0)
-	time_event_add(time(NULL)+_weather_periodic_update*60,AUTOUPDATE);
+    if(app->update_interval > 0)
+	time_event_add(time(NULL)+ app->update_interval * 60, AUTOUPDATE);
 }
 
 /* Remove periodic time event  from list */	  
