@@ -33,14 +33,10 @@
 
 #include "weather-home_common.h"
 
-void timer_handler(gpointer data);
+gboolean timer_handler(gpointer data);
 void timer(void);
 void remove_periodic_event(void);
-guint flag_event=0;  
-extern GtkWidget *box;
-extern GSList *event_time_list;
-extern int _weather_periodic_update;
-extern gchar *_weather_dir_name;
+void print_list(void);
 extern gboolean not_event;
 
 #endif
