@@ -34,32 +34,16 @@
 #define OMW_RESPONSE_ADD_CUSTOM_STATION 10000
 #include "weather-home_common.h"
 
-extern GtkWidget *box;
-extern gchar     *_weather_dir_name;
-extern gchar     *_weather_country_name;
-extern gchar     *_weather_state_name;
-extern gchar     *_weather_station_name;
-extern gchar     *_weather_station_id;
-extern gchar     *_weather_icon_size;
-extern gboolean  _enable_transparency;
-extern int       _weather_periodic_update;
-extern GdkColor  _weather_font_color;
-extern GtkWidget *weather_window_popup;  
 extern GSList    *time_update_list;
-extern gchar     _weather_temperature_unit;
 extern gboolean  not_event;
-extern int       _weather_layout;
-/* by Pavel */
-extern	gint	days_to_show;
-extern	gint	distance_units;
-extern	gchar	*icon_set;
 extern	gchar	path_large_icon[_POSIX_PATH_MAX];
 
 void weather_window_preference (GtkWidget *widget,GdkEvent *event,gpointer user_data);
 void fill_station_list_view (GtkWidget *station_list_view,GtkListStore *station_list_store);
+void station_list_view_select_handler(GtkTreeView *tree_view, gpointer user_data);
 
 GtkWidget  *countrys, *states, *stations, *icon_size, *layout_type, *update_time, *temperature_unit, *days_number;
-GtkWidget  *custom_station_name, *custom_station_code, *units, *iconset;
+GtkWidget  *custom_station_name, *custom_station_code, *units, *iconset, *wunits;
 
 static GSList *stations_list_in_state = NULL; /* Station list of country or state or province.  Use in combobox*/
 static GtkListStore *station_list_store;
